package com.ruoyi.invest.mapper;

import java.util.List;
import com.ruoyi.invest.domain.HeartJourney;
import com.ruoyi.invest.domain.dto.HeartJourneyDto;
import com.ruoyi.invest.domain.vo.HeartJourneyVo;

/**
 * 心路历程Mapper接口
 *
 * @author tianyongbao
 * @date 2024-04-09
 */
public interface HeartJourneyMapper
{
    /**
     * 查询心路历程
     *
     * @param id 心路历程主键
     * @return 心路历程
     */
    public HeartJourneyVo selectHeartJourneyById(Long id);

    /**
     * 查询心路历程列表
     *
     * @param heartJourneyDto 心路历程
     * @return 心路历程集合
     */
    public List<HeartJourneyVo> selectHeartJourneyList(HeartJourneyDto heartJourneyDto);

    /**
     * 新增心路历程
     *
     * @param heartJourney 心路历程
     * @return 结果
     */
    public int insertHeartJourney(HeartJourney heartJourney);

    /**
     * 修改心路历程
     *
     * @param heartJourney 心路历程
     * @return 结果
     */
    public int updateHeartJourney(HeartJourney heartJourney);

    /**
     * 删除心路历程
     *
     * @param id 心路历程主键
     * @return 结果
     */
    public int deleteHeartJourneyById(Long id);

    /**
     * 批量删除心路历程
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteHeartJourneyByIds(Long[] ids);

    /**
     * 逻辑删除心路历程
     *
     * @param id 心路历程主键
     * @return 结果
     */
    public int removeHeartJourneyById(Long id);

    /**
     * 批量逻辑删除心路历程
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int removeHeartJourneyByIds(Long[] ids);
}
